@@ -11,12 +11,10 @@ import logging
 import uuid
 
 from datetime import datetime
-from signal import (
-        signal, default_int_handler, SIGINT
-)
+from signal import signal, default_int_handler, SIGINT
 
 import zmq
-from zmq.eventloop import ioloop
+from tornado import ioloop
 from zmq.eventloop.zmqstream import ZMQStream
 
 from traitlets.config.configurable import SingletonConfigurable
@@ -25,7 +23,7 @@ from ipython_genutils import py3compat
 from ipython_genutils.py3compat import unicode_type, string_types
 from ipykernel.jsonutil import json_clean
 from traitlets import (
-    Any, Instance, Float, Dict, List, Set, Integer, Unicode, Bool,
+    Any, Instance, Float, Dict, List, Set, Integer, Unicode, Bool, observe, default
 )
 
 from jupyter_client.session import Session
@@ -40,7 +38,9 @@ class Kernel(SingletonConfigurable):
 
     # attribute to override with a GUI
     eventloop = Any(None)
-    def _eventloop_changed(self, name, old, new):
+
+    @observe('eventloop')
+    def _update_eventloop(self, change):
         """schedule call to eventloop from IOLoop"""
         loop = ioloop.IOLoop.instance()
         loop.add_callback(self.enter_eventloop)
@@ -58,7 +58,8 @@ class Kernel(SingletonConfigurable):
     int_id = Integer(-1)
     ident = Unicode()
 
-    def _ident_default(self):
+    @default('ident')
+    def _default_ident(self):
         return unicode_type(uuid.uuid4())
 
     # This should be overridden by wrapper kernels that implement any real
@@ -70,12 +71,12 @@ class Kernel(SingletonConfigurable):
 
     # Private interface
 
-    _darwin_app_nap = Bool(True, config=True,
+    _darwin_app_nap = Bool(True,
         help="""Whether to use appnope for compatiblity with OS X App Nap.
 
         Only affects OS X >= 10.9.
         """
-    )
+    ).tag(config=True)
 
     # track associations with current request
     _allow_stdin = Bool(False)
@@ -88,12 +89,12 @@ class Kernel(SingletonConfigurable):
     # Units are in seconds.  The minimum zmq latency on local host is probably
     # ~150 microseconds, set this to 500us for now.  We may need to increase it
     # a little if it's not enough after more interactive testing.
-    _execute_sleep = Float(0.0005, config=True)
+    _execute_sleep = Float(0.0005).tag(config=True)
 
     # Frequency of the kernel's event loop.
     # Units are in seconds, kernel subclasses for GUI toolkits may need to
     # adapt to milliseconds.
-    _poll_interval = Float(0.05, config=True)
+    _poll_interval = Float(0.05).tag(config=True)
 
     # If the shutdown was requested over the network, we leave here the
     # necessary reply message so it can be sent by our registered atexit
@@ -112,7 +113,7 @@ class Kernel(SingletonConfigurable):
     # Track execution count here. For IPython, we override this to use the
     # execution count we store in the shell.
     execution_count = 0
-    
+
     msg_types = [
         'execute_request', 'complete_request',
         'inspect_request', 'history_request',
@@ -137,7 +138,6 @@ class Kernel(SingletonConfigurable):
         for msg_type in self.control_msg_types:
             self.control_handlers[msg_type] = getattr(self, msg_type)
 
-
     def dispatch_control(self, msg):
         """dispatch control requests"""
         idents,msg = self.session.feed_identities(msg, copy=False)
@@ -171,7 +171,7 @@ class Kernel(SingletonConfigurable):
 
     def should_handle(self, stream, msg, idents):
         """Check whether a shell-channel message should be handled
-        
+
         Allows subclasses to prevent handling of certain messages (e.g. aborted requests).
         """
         msg_id = msg['header']['msg_id']
@@ -291,7 +291,6 @@ class Kernel(SingletonConfigurable):
             stream.flush(zmq.POLLIN, 1)
             stream.flush(zmq.POLLOUT)
 
-
     def record_ports(self, ports):
         """Record the ports that this kernel is using.
 
@@ -345,19 +344,19 @@ class Kernel(SingletonConfigurable):
         """
         return self.session.send(stream, msg_or_type, content, self._parent_header,
                                  ident, buffers, track, header, metadata)
-    
+
     def init_metadata(self, parent):
         """Initialize metadata.
-        
+
         Run at the beginning of execution requests.
         """
         return {
             'started': datetime.now(),
         }
-    
+
     def finish_metadata(self, parent, metadata, reply_content):
         """Finish populating metadata.
-        
+
         Run after completing an execution request.
         """
         return metadata
@@ -468,13 +467,14 @@ class Kernel(SingletonConfigurable):
                    stop=None, n=None, pattern=None, unique=False):
         """Override in subclasses to access history.
         """
-        return {'history': []}
+        return {'status': 'ok', 'history': []}
 
     def connect_request(self, stream, ident, parent):
         if self._recorded_ports is not None:
             content = self._recorded_ports.copy()
         else:
             content = {}
+        content['status'] = 'ok'
         msg = self.session.send(stream, 'connect_reply',
                                 content, parent, ident)
         self.log.debug("%s", msg)
@@ -491,8 +491,10 @@ class Kernel(SingletonConfigurable):
         }
 
     def kernel_info_request(self, stream, ident, parent):
+        content = {'status': 'ok'}
+        content.update(self.kernel_info)
         msg = self.session.send(stream, 'kernel_info_reply',
-                                self.kernel_info, parent, ident)
+                                content, parent, ident)
         self.log.debug("%s", msg)
 
     def comm_info_request(self, stream, ident, parent):
@@ -508,7 +510,7 @@ class Kernel(SingletonConfigurable):
             }
         else:
             comms = {}
-        reply_content = dict(comms=comms)
+        reply_content = dict(comms=comms, status='ok')
         msg = self.session.send(stream, 'comm_info_reply',
                                 reply_content, parent, ident)
         self.log.debug("%s", msg)
@@ -565,7 +567,7 @@ class Kernel(SingletonConfigurable):
         md = self.init_metadata(parent)
 
         reply_content, result_buf = self.do_apply(content, bufs, msg_id, md)
-        
+
         # flush i/o
         sys.stdout.flush()
         sys.stderr.flush()
@@ -648,7 +650,6 @@ class Kernel(SingletonConfigurable):
             # be set shorter for true asynchronous clients.
             poller.poll(50)
 
-
     def _no_raw_input(self):
         """Raise StdinNotImplentedError if active frontend doesn't support
         stdin."""
@@ -683,7 +684,7 @@ class Kernel(SingletonConfigurable):
             raise StdinNotImplementedError(
                 "raw_input was called, but this frontend does not support input requests."
             )
-        return self._input_request(prompt,
+        return self._input_request(str(prompt),
             self._parent_ident,
             self._parent_header,
             password=False,
